@@ -27,7 +27,6 @@ class SecurityProtocol:
     :type config: Union[str, dict]
     :param results_dir: path to the directory containing the results
     :param train_dir: path to the directory containing the immutable files defining a train
-
     """
 
     def __init__(self, station_id: str, config: Union[str, dict], results_dir: str = None, train_dir: str = None,
@@ -98,8 +97,7 @@ class SecurityProtocol:
             logging.info("Pre-run protocol success")
             return
         else:
-            raise ValueError("Neither instance variables for  train and results directories nor the the mutable files"
-                             "and immutable files arguments are set.")
+            raise ValueError("Neither train image or results and train directories are set")
 
     def post_run_protocol(self, img: str = None, private_key_path: str = None, mutable_dir: str = "/opt/pht_results"):
         """
@@ -433,7 +431,7 @@ class SecurityProtocol:
                               utils.Prehashed(hashes.SHA512())
                               )
 
-    def _is_first_station_on_route(self):
+    def _is_first_station_on_route(self) -> bool:
         """
         Returns true if current station is the first station on the route
         :return:
@@ -455,9 +453,3 @@ class SecurityProtocol:
         logging.info(f"Found {len(files)} Files")
         return files
 
-    def _previous_station_id(self):
-        """
-        :return: station id of previous station on route
-        """
-        # get the key of the last entry in the ds dictionary as the previous station id
-        return self.key_manager.get_security_param("digital_signature")[-1]["station"]
